# AIO Microservice

[![ci](https://img.shields.io/github/actions/workflow/status/betaboon/aio-microservice/ci-main.yaml?style=for-the-badge&branch=main&logo=github&logoColor=white)](https://github.com/betaboon/aio-microservice/actions/workflows/ci-main.yaml?query=branch%3Amain)

[![version](https://img.shields.io/pypi/v/aio-microservice?style=for-the-badge&logo=pypi&logoColor=white)](https://pypi.org/project/aio-microservice)
[![pyversions](https://img.shields.io/pypi/pyversions/aio-microservice?style=for-the-badge&logo=python&logoColor=white)](https://github.com/betaboon/aio-microservice)
[![license](https://img.shields.io/pypi/l/aio-microservice?style=for-the-badge)](https://github.com/betaboon/aio-microservice/LICENSE)

[![docs](https://img.shields.io/badge/docs-blue?style=for-the-badge&label=sphinx&logo=sphinx&logoColor=white)](https://betaboon.github.io/aio-microservice)
[![pdm](https://img.shields.io/badge/managed-blue?style=for-the-badge&logo=pdm&logoColor=white&label=pdm&color=%237e56c2)](https://pdm-project.org)
[![ruff](https://img.shields.io/badge/formatted-blue?style=for-the-badge&logo=ruff&logoColor=white&label=ruff&color=%23d7ff64)](https://astral.sh/ruff)

## What is AIO Microservice?
<!-- start description -->

A library to create microservices.

<!-- end description -->

## Features
<!-- start features -->

<!-- end features -->

## Installation
<!-- start installation -->

AIO Microservice can be installed with `pip`:

```text
pip install aio-microservice
```

<!-- end installation -->

## Quickstart
<!-- start quickstart -->

<!-- end quickstart -->

## Contributing
